Bug#666306: canna: FTBFS: /bin/sh: 1: platex: not found

2012-03-30 Thread Lucas Nussbaum
Source: canna
Version: 3.7p3-8
Severity: serious
Tags: wheezy sid
User: debian...@lists.debian.org
Usertags: qa-ftbfs-20120330 qa-ftbfs qa-ftbfs-buildarch
Justification: FTBFS on amd64

Hi,

During a rebuild of all packages in sid, your package failed to build on
amd64.

This rebuild was done by building only architecture:any binary packages
(binary-arch target of debian/rules), and using a recent dpkg that uses the
build-arch target if available.
Also, only the Build-Depends were installed, not the Build-Depends-Indep.

Relevant part:
> make[2]: Entering directory `/«PKGBUILDDIR»/doc/man/guide/tex'
> (echo "s%@(cannaBinDir)%/usr//bin%g"; \
>echo "s%@(cannaLibDir)%/etc/canna%g"; \
>echo "s%@(cannaIncDir)%/usr//include/canna%g"; \
>echo "s%@(UnixSockDir)%/tmp/.iroha_unix%g"; \
>echo "s%@(UnixSockName)%IROHA%g"; \
>echo "s%@(AccessFile)%/etc/hosts.canna%g"; \
>echo "s%@(DicDir)%/var/lib/canna/dic%g"; \
>echo "s%@(ErrDir)%/var/log/canna%g") > ../../../../misc/manual.sed
> sed -f ../../../../misc/manual.sed canna-dist.tex > canna.tex
> gcc -g -O2 -fno-strict-aliasing-I../../../../include -Dlinux 
> -D__amd64__ -D_POSIX_C_SOURCE=199309L
> -D_POSIX_SOURCE -D_XOPEN_SOURCE -D_BSD_SOURCE 
> -D_SVID_SOURCE -D_LARGEFILE_SOURCE 
> -D_FILE_OFFSET_BITS=64
>-DFUNCPROTO=15 -DNARROWPROTO   -c -o cannaindex.o cannaindex.c
> rm -f cannaindex
> gcc -o cannaindex -g -O2 -fno-strict-aliasing   cannaindex.o   
> echo 'DUMMY' > candex.tex
> platex canna.tex
> /bin/sh: 1: platex: not found
> make[2]: *** [canna.dvi] Error 127

The full build log is available from:
   http://people.debian.org/~lucas/logs/2012/03/30/canna_3.7p3-8_unstable.log

A list of current common problems and possible solutions is available at 
http://wiki.debian.org/qa.debian.org/FTBFS . You're welcome to contribute!

About the archive rebuild: The rebuild was done on about 50 AMD64 nodes
of the Grid'5000 platform, using a clean chroot.  Internet was not
accessible from the build systems.



-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/20120330092151.ga26...@xanadu.blop.info



Bug#666347: toshset: FTBFS: make[1]: *** No targets specified and no makefile found. Stop.

2012-03-30 Thread Lucas Nussbaum
Source: toshset
Version: 1.76-2
Severity: serious
Tags: wheezy sid
User: debian...@lists.debian.org
Usertags: qa-ftbfs-20120330 qa-ftbfs qa-ftbfs-buildarch
Justification: FTBFS on amd64

Hi,

During a rebuild of all packages in sid, your package failed to build on
amd64.

This rebuild was done by building only architecture:any binary packages
(binary-arch target of debian/rules), and using a recent dpkg that uses the
build-arch target if available.
Also, only the Build-Depends were installed, not the Build-Depends-Indep.

Relevant part:
>  debian/rules build-arch
> dh_testdir
> /usr/bin/make
> make[1]: Entering directory `/«PKGBUILDDIR»'
> make[1]: *** No targets specified and no makefile found.  Stop.
> make[1]: Leaving directory `/«PKGBUILDDIR»'
> make: *** [build-stamp] Error 2

The full build log is available from:
   http://people.debian.org/~lucas/logs/2012/03/30/toshset_1.76-2_unstable.log

A list of current common problems and possible solutions is available at 
http://wiki.debian.org/qa.debian.org/FTBFS . You're welcome to contribute!

About the archive rebuild: The rebuild was done on about 50 AMD64 nodes
of the Grid'5000 platform, using a clean chroot.  Internet was not
accessible from the build systems.



-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/20120330092916.ga27...@xanadu.blop.info



Bug#575324: exactimage: file format misdetection

2012-03-30 Thread Sven Eckelmann
tags 575324 + patch
thanks

On Wednesday, March 24, 2010 10:40:32 PM you wrote:
> Package: exactimage
> Version: 0.7.5-3
> Severity: minor
> 
> y.pbm is a perfectly valid PBM file:
> 
> $ edentify y.pbm
> TGA: 80, 10, 1, 52, 255, 65343, ÿ
> y.pbm: TARGA 255x65343 0 bit, 3 channels

The problem seems to be that the TARGA codec is added too early to the codec 
datastructure. I worked around that problem using different strategies to 
insert the codec. 

Kind regards,
SvenDescription: Add missing includes for std::vector
Author: Sven Eckelmann 

---
diff --git a/codecs/pdf.hh b/codecs/pdf.hh
index 6beec621f75e18d4438866d80c8c41a0fd382f8f..0bf3f553494c5ae0ffcd1fe7ea4b7c6dc71a1145 100644
--- a/codecs/pdf.hh
+++ b/codecs/pdf.hh
@@ -16,6 +16,8 @@
  * copyright holder ExactCODE GmbH Germany.
  */
 
+#include 
+
 #include "Codecs.hh"
 
 struct PDFContext; // fwd
diff --git a/codecs/xpm.cc b/codecs/xpm.cc
index 7736e3e70e1000a181c4e018e8595ebaf42e7cfa..0bf04b2ae2980acca0a5f9feb22d14fca37f8543 100644
--- a/codecs/xpm.cc
+++ b/codecs/xpm.cc
@@ -19,6 +19,7 @@
 #include 
 #include 
 #include 
+#include 
 
 #include "xpm.hh"
 
diff --git a/lib/Colorspace.cc b/lib/Colorspace.cc
index 13df3513c66461d33eafb1a1b406700ac9cd0baf..832d88e05921cb2d2369368db2ea4cb9b8d3f24a 100644
--- a/lib/Colorspace.cc
+++ b/lib/Colorspace.cc
@@ -19,6 +19,7 @@
 
 #include 
 #include 
+#include 
 
 #include "Image.hh"
 #include "ImageIterator2.hh"
Description: Fix misidentification of PNM as TGA
 TARGA files have nearly no magic values that can be used to distinguish them
 from other files. Therefore, it is important to test the other file codec
 handlers before testing for TARGA.
Author: Sven Eckelmann 

---
diff --git a/codecs/Codecs.cc b/codecs/Codecs.cc
index 803e3e2e8f92ee8118a2512529c718e848241984..054548ff61db2f7dc82d24a32f40d8f512cb2dfb 100644
--- a/codecs/Codecs.cc
+++ b/codecs/Codecs.cc
@@ -22,7 +22,7 @@
 #include 
 #include 
 
-std::vector* ImageCodec::loader = 0;
+std::list* ImageCodec::loader = 0;
 
 ImageCodec::ImageCodec ()
   : _image (0)
@@ -78,7 +78,7 @@ int ImageCodec::Read (std::istream* stream, Image& image,
 {
   std::transform (codec.begin(), codec.end(), codec.begin(), tolower);
   
-  std::vector::iterator it;
+  std::list::iterator it;
   if (loader)
   for (it = loader->begin(); it != loader->end(); ++it)
 {
@@ -116,7 +116,7 @@ bool ImageCodec::Write (std::ostream* stream, Image& image,
   std::transform (codec.begin(), codec.end(), codec.begin(), tolower);
   std::transform (ext.begin(), ext.end(), ext.begin(), tolower);
   
-  std::vector::iterator it;
+  std::list::iterator it;
   if (loader)
   for (it = loader->begin(); it != loader->end(); ++it)
 {
@@ -150,7 +150,7 @@ ImageCodec* ImageCodec::MultiWrite (std::ostream* stream,
   std::transform (codec.begin(), codec.end(), codec.begin(), tolower);
   std::transform (ext.begin(), ext.end(), ext.begin(), tolower);
   
-  std::vector::iterator it;
+  std::list::iterator it;
   if (loader)
   for (it = loader->begin(); it != loader->end(); ++it)
 {
@@ -222,14 +222,17 @@ bool ImageCodec::Write (std::string file, Image& image,
 }
 
 void ImageCodec::registerCodec (const char* _ext, ImageCodec* _loader,
-bool _via_codec_only)
+bool _via_codec_only, bool push_back)
 {
   static ImageCodec* last_loader = 0;
   if (!loader)
-loader = new std::vector;
+loader = new std::list;
   
   loader_ref ref = {_ext, _loader, _loader != last_loader, _via_codec_only};
-  loader->push_back(ref);
+  if (push_back)
+loader->push_back(ref);
+  else
+loader->push_front(ref);
   last_loader = _loader;
 }
 
@@ -241,7 +244,7 @@ void ImageCodec::unregisterCodec (ImageCodec* _loader)
   }
   
   // remove from array
-  std::vector::iterator it;
+  std::list::iterator it;
   for (it = loader->begin(); it != loader->end();)
 if (it->loader == _loader)
   it = loader->erase (it);
diff --git a/codecs/Codecs.hh b/codecs/Codecs.hh
index e30a6b681cf6acc58173d41be023ea72852cb3d6..08790a14be44e9dde8721c1057a96d0b43a85e9d 100644
--- a/codecs/Codecs.hh
+++ b/codecs/Codecs.hh
@@ -18,7 +18,7 @@
 /* The Image decoder and coder collection.
  *
  * The class itself has static methods to perform the de- and
  * encoding. These methods search thru a loader vector to match the
  * file magick (on decoding) or the specified codec / file extension
  * on encoding.
  *
@@ -36,7 +36,7 @@
 
 #include 
 
-#include 
+#include 
 #include 
 #include 
 
@@ -111,11 +111,12 @@ protected:
 bool via_codec_only;
   };
   
-  static std::vector* loader;
+  static std::list* loader;
   
   static void registerCodec (const char* _ext,
 			 ImageCodec* _loader,
-			 bool _via_codec_only = false);
+			 bool _via_codec_only = false,
+			 bool push_back = false);
   static void unregisterCodec (ImageCodec* _loader);
   
   // freestanding instance, attached to an image
@@ -18,7 +18,7 @@
  *
  * The class itself has static methods to perform the de- and
- * encoding. These methods search thru a loader vector to match the
+ * encoding. These methods search thru a loader list to match the
  * file magick (on decoding) or the specified codec / file extension
  * on encoding.
diff --git a/codecs/tga.hh b/cod

Processed: Re: exactimage: file format misdetection

2012-03-30 Thread Debian Bug Tracking System
Processing commands for cont...@bugs.debian.org:

> tags 575324 + patch
Bug #575324 [exactimage] exactimage: file format misdetection
Added tag(s) patch.
> thanks
Stopping processing here.

Please contact me if you need assistance.
-- 
575324: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=575324
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems


--
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: 
http://lists.debian.org/handler.s.c.13331050986661.transcr...@bugs.debian.org



Processed: Re: exactimage: Please Build-Depends on libpng-dev, change from libpng12-dev

2012-03-30 Thread Debian Bug Tracking System
Processing commands for cont...@bugs.debian.org:

> tags 662317 + pending
Bug #662317 [src:exactimage] exactimage: Please Build-Depends on libpng-dev, 
change from libpng12-dev
Added tag(s) pending.
> thanks
Stopping processing here.

Please contact me if you need assistance.
-- 
662317: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=662317
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems


--
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: 
http://lists.debian.org/handler.s.c.133310882624623.transcr...@bugs.debian.org



Processed: Re: econvert: Incorrect output from SVG to PNG

2012-03-30 Thread Debian Bug Tracking System
Processing commands for cont...@bugs.debian.org:

> reassign 522360 libagg-dev 2.5+dfsg1-4
Bug #522360 [exactimage] econvert: Incorrect output from SVG to PNG
Bug reassigned from package 'exactimage' to 'libagg-dev'.
No longer marked as found in versions exactimage/0.7.1-1.
Ignoring request to alter fixed versions of bug #522360 to the same values 
previously set
Bug #522360 [libagg-dev] econvert: Incorrect output from SVG to PNG
Marked as found in versions agg/2.5+dfsg1-4.
> thanks
Stopping processing here.

Please contact me if you need assistance.
-- 
522360: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=522360
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems


--
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: 
http://lists.debian.org/handler.s.c.1333282392.transcr...@bugs.debian.org



Processing of canna_3.7p3-9_amd64.changes

2012-03-30 Thread Debian FTP Masters
canna_3.7p3-9_amd64.changes uploaded successfully to localhost
along with the files:
  canna_3.7p3-9.dsc
  canna_3.7p3-9.debian.tar.gz
  canna_3.7p3-9_amd64.deb
  canna-utils_3.7p3-9_amd64.deb
  libcanna1g_3.7p3-9_amd64.deb
  libcanna1g-dev_3.7p3-9_amd64.deb

Greetings,

Your Debian queue daemon (running on host franck.debian.org)


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sddnx-0001fj...@franck.debian.org



Bug#666306: marked as done (canna: FTBFS: /bin/sh: 1: platex: not found)

2012-03-30 Thread Debian Bug Tracking System
Your message dated Fri, 30 Mar 2012 15:47:57 +
with message-id 
and subject line Bug#666306: fixed in canna 3.7p3-9
has caused the Debian Bug report #666306,
regarding canna: FTBFS: /bin/sh: 1: platex: not found
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact ow...@bugs.debian.org
immediately.)


-- 
666306: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=666306
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems
--- Begin Message ---
Source: canna
Version: 3.7p3-8
Severity: serious
Tags: wheezy sid
User: debian...@lists.debian.org
Usertags: qa-ftbfs-20120330 qa-ftbfs qa-ftbfs-buildarch
Justification: FTBFS on amd64

Hi,

During a rebuild of all packages in sid, your package failed to build on
amd64.

This rebuild was done by building only architecture:any binary packages
(binary-arch target of debian/rules), and using a recent dpkg that uses the
build-arch target if available.
Also, only the Build-Depends were installed, not the Build-Depends-Indep.

Relevant part:
> make[2]: Entering directory `/«PKGBUILDDIR»/doc/man/guide/tex'
> (echo "s%@(cannaBinDir)%/usr//bin%g"; \
>echo "s%@(cannaLibDir)%/etc/canna%g"; \
>echo "s%@(cannaIncDir)%/usr//include/canna%g"; \
>echo "s%@(UnixSockDir)%/tmp/.iroha_unix%g"; \
>echo "s%@(UnixSockName)%IROHA%g"; \
>echo "s%@(AccessFile)%/etc/hosts.canna%g"; \
>echo "s%@(DicDir)%/var/lib/canna/dic%g"; \
>echo "s%@(ErrDir)%/var/log/canna%g") > ../../../../misc/manual.sed
> sed -f ../../../../misc/manual.sed canna-dist.tex > canna.tex
> gcc -g -O2 -fno-strict-aliasing-I../../../../include -Dlinux 
> -D__amd64__ -D_POSIX_C_SOURCE=199309L
> -D_POSIX_SOURCE -D_XOPEN_SOURCE -D_BSD_SOURCE 
> -D_SVID_SOURCE -D_LARGEFILE_SOURCE 
> -D_FILE_OFFSET_BITS=64
>-DFUNCPROTO=15 -DNARROWPROTO   -c -o cannaindex.o cannaindex.c
> rm -f cannaindex
> gcc -o cannaindex -g -O2 -fno-strict-aliasing   cannaindex.o   
> echo 'DUMMY' > candex.tex
> platex canna.tex
> /bin/sh: 1: platex: not found
> make[2]: *** [canna.dvi] Error 127

The full build log is available from:
   http://people.debian.org/~lucas/logs/2012/03/30/canna_3.7p3-8_unstable.log

A list of current common problems and possible solutions is available at 
http://wiki.debian.org/qa.debian.org/FTBFS . You're welcome to contribute!

About the archive rebuild: The rebuild was done on about 50 AMD64 nodes
of the Grid'5000 platform, using a clean chroot.  Internet was not
accessible from the build systems.


--- End Message ---
--- Begin Message ---
Source: canna
Source-Version: 3.7p3-9

We believe that the bug you reported is fixed in the latest version of
canna, which is due to be installed in the Debian FTP archive:

canna-utils_3.7p3-9_amd64.deb
  to main/c/canna/canna-utils_3.7p3-9_amd64.deb
canna_3.7p3-9.debian.tar.gz
  to main/c/canna/canna_3.7p3-9.debian.tar.gz
canna_3.7p3-9.dsc
  to main/c/canna/canna_3.7p3-9.dsc
canna_3.7p3-9_amd64.deb
  to main/c/canna/canna_3.7p3-9_amd64.deb
libcanna1g-dev_3.7p3-9_amd64.deb
  to main/c/canna/libcanna1g-dev_3.7p3-9_amd64.deb
libcanna1g_3.7p3-9_amd64.deb
  to main/c/canna/libcanna1g_3.7p3-9_amd64.deb



A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to 666...@bugs.debian.org,
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
HIGUCHI Daisuke (VDR dai)  (supplier of updated canna package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing ftpmas...@debian.org)


-BEGIN PGP SIGNED MESSAGE-
Hash: SHA256

Format: 1.8
Date: Fri, 30 Mar 2012 23:51:21 +0900
Source: canna
Binary: canna canna-utils libcanna1g libcanna1g-dev
Architecture: source amd64
Version: 3.7p3-9
Distribution: unstable
Urgency: low
Maintainer: Debian QA Group 
Changed-By: HIGUCHI Daisuke (VDR dai) 
Description: 
 canna  - input system for Japanese - server and dictionary
 canna-utils - input system for Japanese - utilities
 libcanna1g - input system for Japanese - runtime library
 libcanna1g-dev - input system for Japanese - development files
Closes: 666306
Cha

canna_3.7p3-9_amd64.changes ACCEPTED into unstable

2012-03-30 Thread Debian FTP Masters



Accepted:
canna-utils_3.7p3-9_amd64.deb
  to main/c/canna/canna-utils_3.7p3-9_amd64.deb
canna_3.7p3-9.debian.tar.gz
  to main/c/canna/canna_3.7p3-9.debian.tar.gz
canna_3.7p3-9.dsc
  to main/c/canna/canna_3.7p3-9.dsc
canna_3.7p3-9_amd64.deb
  to main/c/canna/canna_3.7p3-9_amd64.deb
libcanna1g-dev_3.7p3-9_amd64.deb
  to main/c/canna/libcanna1g-dev_3.7p3-9_amd64.deb
libcanna1g_3.7p3-9_amd64.deb
  to main/c/canna/libcanna1g_3.7p3-9_amd64.deb


Changes:
canna (3.7p3-9) unstable; urgency=low
 .
  * QA upload.
  * B-D: texlive-lang-cjk instead of ptex-bin (Closes: #666306).
- debian/control: updated B-D:
- debian/patches/04_platex.patch: added --kanji=euc option.
  * debian/control: fix Vcs-Browser:


Override entries for your package:
canna-utils_3.7p3-9_amd64.deb - optional utils
canna_3.7p3-9.dsc - source utils
canna_3.7p3-9_amd64.deb - optional utils
libcanna1g-dev_3.7p3-9_amd64.deb - optional libdevel
libcanna1g_3.7p3-9_amd64.deb - optional libs

Announcing to debian-devel-chan...@lists.debian.org
Closing bugs: 666306 


Thank you for your contribution to Debian.


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sde3r-0003hw...@franck.debian.org



Processing of libtextcat_2.2-11_amd64.changes

2012-03-30 Thread Debian FTP Masters
libtextcat_2.2-11_amd64.changes uploaded successfully to localhost
along with the files:
  libtextcat_2.2-11.dsc
  libtextcat_2.2-11.debian.tar.gz
  libtextcat-data_2.2-11_all.deb
  libtextcat0_2.2-11_amd64.deb
  libtextcat-dev_2.2-11_amd64.deb

Greetings,

Your Debian queue daemon (running on host franck.debian.org)


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdfde-0006ag...@franck.debian.org



libtextcat_2.2-11_amd64.changes ACCEPTED into unstable

2012-03-30 Thread Debian FTP Masters



Accepted:
libtextcat-data_2.2-11_all.deb
  to main/libt/libtextcat/libtextcat-data_2.2-11_all.deb
libtextcat-dev_2.2-11_amd64.deb
  to main/libt/libtextcat/libtextcat-dev_2.2-11_amd64.deb
libtextcat0_2.2-11_amd64.deb
  to main/libt/libtextcat/libtextcat0_2.2-11_amd64.deb
libtextcat_2.2-11.debian.tar.gz
  to main/libt/libtextcat/libtextcat_2.2-11.debian.tar.gz
libtextcat_2.2-11.dsc
  to main/libt/libtextcat/libtextcat_2.2-11.dsc


Changes:
libtextcat (2.2-11) unstable; urgency=low
 .
  * orphan package, set Maintainer to Debian QA Group
  * stop building createftp as it is built by libexttextcat since long


Override entries for your package:
libtextcat-data_2.2-11_all.deb - optional text
libtextcat-dev_2.2-11_amd64.deb - optional libdevel
libtextcat0_2.2-11_amd64.deb - optional libs
libtextcat_2.2-11.dsc - source libs

Announcing to debian-devel-chan...@lists.debian.org


Thank you for your contribution to Debian.


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdfuh-0003e7...@franck.debian.org



Processed: makedev: merge two reports relating to GNU/kFreeBSD

2012-03-30 Thread Debian Bug Tracking System
Processing commands for cont...@bugs.debian.org:

> package makedev
Limiting to bugs with field 'package' containing at least one of 'makedev'
Limit currently set to 'package':'makedev'

> severity 665472 serious
Bug #665472 [makedev] [makedev] Aborts on kfreebsd while upgrade unable to find 
/dev/tty[0-9]*
Severity set to 'serious' from 'grave'
> merge 665461 665472
Bug #665461 [makedev] makedev.postinst for GNU/kFreeBSD
Bug #665472 [makedev] [makedev] Aborts on kfreebsd while upgrade unable to find 
/dev/tty[0-9]*
Merged 665461 665472
> thanks
Stopping processing here.

Please contact me if you need assistance.
-- 
665461: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=665461
665472: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=665472
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems


--
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: 
http://lists.debian.org/handler.s.c.133313984313023.transcr...@bugs.debian.org



Bug#665461: makedev: GNU/kFreeBSD needs ttyv[0-9]*.

2012-03-30 Thread Mats Erik Andersson
Usertags: kfreebsd

The postinst script is Linux-only. The following change produces a working
package also for GNU/kFreeBSD.

The package is assigned to the Debian QA group, so the glibc-bsd group or
Bdale Garbee are most likely to act on this.

Observe the additional change "chmod g-rw", since otherwise the tty group
wuld have had write access to the device on GNU/kFreeBSD.

Regards,
  Mats Erik Andersson, DM


--- /var/lib/dpkg/info/makedev.postinst.orig2012-03-21 11:00:59.0 
+0100
+++ /var/lib/dpkg/info/makedev.postinst 2012-03-30 22:04:35.981619170 +0200
@@ -14,12 +14,18 @@
 
 MAKEDEV std consoleonly fd
 
+# Device string for GNU/Linux
+TTY=tty
+
+# Overriding string for other ports
+test `uname -s` = "GNU/kFreeBSD" && TTY=ttyv
+
 # ensure base tty set exists, since debootstrap no longer does
-for i in tty0 tty1 tty2 tty3 tty4 tty5 tty6 tty7 tty8 tty9; do
-   test -e /dev/$i || MAKEDEV $i
+for i in 0 1 2 3 4 5 6 7 8 9; do
+   test -e /dev/$TTY$i || MAKEDEV $TTY$i
 done
 
-chmod g-r,o= /dev/tty[0-9]*
+chmod g-rw,o= /dev/$TTY[0-9]*
 
 test -e /dev/random || MAKEDEV random
 test -e /dev/urandom || MAKEDEV urandom



-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/20120330203515.ga9...@mea.homelinux.org



Bug#665461: Bug #665461: makedev: GNU/kFreeBSD needs ttyv[0-9]*.

2012-03-30 Thread Robert Millan
Hi Mats,

El 30 de març de 2012 23:15, Mats Erik Andersson
 ha escrit:
> The postinst script is Linux-only. The following change produces a working
> package also for GNU/kFreeBSD.

Why not just use devfs?  makedev is deprecated on both platforms.

-- 
Robert Millan



--
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: 
http://lists.debian.org/CAOfDtXP8AMPdwaq4=TPO1Bpb2J6suWnrWK=_pwcepuend-l...@mail.gmail.com



Bug#665461: Bug #665461: makedev: GNU/kFreeBSD needs ttyv[0-9]*.

2012-03-30 Thread Mats Erik Andersson
lördag den 31 mars 2012 klockan 00:08 skrev Robert Millan detta:
> Hi Mats,
> 
> El 30 de març de 2012 23:15, Mats Erik Andersson
>  ha escrit:
> > The postinst script is Linux-only. The following change produces a working
> > package also for GNU/kFreeBSD.
> 
> Why not just use devfs?  makedev is deprecated on both platforms.

The install image for GNU/kFreeBSD from last summer forced
makedev upon me, and now when I conducted an upgrade, this
bug hit me, and an hour later also a user in Argentine,
see #665472.

I have merged the two bugs into one; not sure how to
proceed. Bdale Garbee updated makedev eight days ago,
and has received a copy of this suggestion in mending
the package. With some luck he will contribute with ideas.

Regards,
  Mats E A



-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/20120330222616.ga11...@mea.homelinux.org



Bug#662003: apt-move with SHA256 support?

2012-03-30 Thread Herbert Xu
Hi:

Do we still need MD5 sums in the Packages file? If not I'd
suggest simply changing all existing references to md5 with
sha256 and it should just work.

Cheers,
-- 
Email: Herbert Xu 
Home Page: http://gondor.apana.org.au/~herbert/
PGP Key: http://gondor.apana.org.au/~herbert/pubkey.txt



-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/20120331010717.ga2...@gondor.apana.org.au



Processing of svgalib_1.4.3-32_amd64.changes

2012-03-30 Thread Debian FTP Masters
svgalib_1.4.3-32_amd64.changes uploaded successfully to ftp-master.debian.org
along with the files:
  svgalib_1.4.3-32.dsc
  svgalib_1.4.3-32.debian.tar.gz
  svgalib-bin_1.4.3-32_amd64.deb
  libsvga1_1.4.3-32_amd64.deb
  libsvga1-dev_1.4.3-32_amd64.deb

Greetings,

Your Debian queue daemon (running on host ravel.debian.org)


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdqjn-0006u2...@ravel.debian.org



Processing of svgalib_1.9.25-2_amd64.changes

2012-03-30 Thread Debian FTP Masters
svgalib_1.9.25-2_amd64.changes uploaded successfully to ftp-master.debian.org
along with the files:
  svgalib_1.9.25-2.dsc
  svgalib_1.9.25-2.debian.tar.gz
  svgalib-bin_1.9.25-2_amd64.deb
  libsvga1_1.9.25-2_amd64.deb
  libsvga1-dev_1.9.25-2_amd64.deb

Greetings,

Your Debian queue daemon (running on host ravel.debian.org)


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdqjs-0006uc...@ravel.debian.org



Processing of svgalib_1.9.25-2_amd64.changes

2012-03-30 Thread Debian FTP Masters
svgalib_1.9.25-2_amd64.changes uploaded successfully to localhost
along with the files:
  svgalib_1.9.25-2.dsc
  svgalib_1.9.25-2.debian.tar.gz
  svgalib-bin_1.9.25-2_amd64.deb
  libsvga1_1.9.25-2_amd64.deb
  libsvga1-dev_1.9.25-2_amd64.deb

Greetings,

Your Debian queue daemon (running on host franck.debian.org)


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdqnv-0002dg...@franck.debian.org



Processing of svgalib_1.4.3-32_amd64.changes

2012-03-30 Thread Debian FTP Masters
svgalib_1.4.3-32_amd64.changes uploaded successfully to localhost
along with the files:
  svgalib_1.4.3-32.dsc
  svgalib_1.4.3-32.debian.tar.gz
  svgalib-bin_1.4.3-32_amd64.deb
  libsvga1_1.4.3-32_amd64.deb
  libsvga1-dev_1.4.3-32_amd64.deb

Greetings,

Your Debian queue daemon (running on host franck.debian.org)


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdqnu-0002cu...@franck.debian.org



svgalib_1.4.3-32_amd64.changes ACCEPTED into unstable

2012-03-30 Thread Debian FTP Masters



Accepted:
libsvga1-dev_1.4.3-32_amd64.deb
  to main/s/svgalib/libsvga1-dev_1.4.3-32_amd64.deb
libsvga1_1.4.3-32_amd64.deb
  to main/s/svgalib/libsvga1_1.4.3-32_amd64.deb
svgalib-bin_1.4.3-32_amd64.deb
  to main/s/svgalib/svgalib-bin_1.4.3-32_amd64.deb
svgalib_1.4.3-32.debian.tar.gz
  to main/s/svgalib/svgalib_1.4.3-32.debian.tar.gz
svgalib_1.4.3-32.dsc
  to main/s/svgalib/svgalib_1.4.3-32.dsc


Changes:
svgalib (1:1.4.3-32) unstable; urgency=low
 .
  * Orphan package, set maintainer to Debian QA Group.
  * Use which instead of “command -v” in svgalib-bin.init.
  * Quote `which file` invokation so that “test -x” does not succeed on an
empty string, causing svgalib-bin.init to fail when the package is
removed but not purged. (Closes: #644264)
  * Rename debian/libsvga1.copyright to debian/copyright, and use
«dh_installdocs --link-doc» instead of manual links through dh_link.
  * Now using Standards-Version 3.9.3 (no changes needed).
  * Remove commented out debhelper commands in debian/rules.
  * Move doc/TODO from libsvga1 to libsvga1-dev, and do not install
0-README into libsvga1.
  * Make shared library packages multiarch:
- Build-Depend on debhelper 8.1.3.
- Add misc:Pre-Depends substvar to Pre-Depends field in libsvga1.
- Add “Multi-Arch: same” field to libsvga1.
- Define DEB_HOST_MULTIARCH and use it to set libdir.
- Change paths from lib/ to lib/* in debian/rules.
  * Cleanup debian/rules targets:
- Rename build to build-arch, add empty build-indep.
- Add new build target depending on build-indep and build-arch.
- Rename install to install-arch.
- Change install-arch to depend on build-arch.
- Change binary-arch to depend only on install-arch.
- Do not do anything in binary-indep.


Override entries for your package:
libsvga1-dev_1.4.3-32_amd64.deb - optional libdevel
libsvga1_1.4.3-32_amd64.deb - optional libs
svgalib-bin_1.4.3-32_amd64.deb - optional graphics
svgalib_1.4.3-32.dsc - source libs

Announcing to debian-devel-chan...@lists.debian.org
Closing bugs: 644264 


Thank you for your contribution to Debian.


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdquv-0003nk...@franck.debian.org



svgalib_1.9.25-2_amd64.changes ACCEPTED into experimental

2012-03-30 Thread Debian FTP Masters



Accepted:
libsvga1-dev_1.9.25-2_amd64.deb
  to main/s/svgalib/libsvga1-dev_1.9.25-2_amd64.deb
libsvga1_1.9.25-2_amd64.deb
  to main/s/svgalib/libsvga1_1.9.25-2_amd64.deb
svgalib-bin_1.9.25-2_amd64.deb
  to main/s/svgalib/svgalib-bin_1.9.25-2_amd64.deb
svgalib_1.9.25-2.debian.tar.gz
  to main/s/svgalib/svgalib_1.9.25-2.debian.tar.gz
svgalib_1.9.25-2.dsc
  to main/s/svgalib/svgalib_1.9.25-2.dsc


Changes:
svgalib (1:1.9.25-2) experimental; urgency=low
 .
  * Orphan package, set maintainer to Debian QA Group.
  * Merge 1:1.4.3-23 to 1:1.4.3-32 from unstable.


Override entries for your package:
libsvga1-dev_1.9.25-2_amd64.deb - optional libdevel
libsvga1_1.9.25-2_amd64.deb - optional libs
svgalib-bin_1.9.25-2_amd64.deb - optional graphics
svgalib_1.9.25-2.dsc - source libs

Announcing to debian-experimental-chan...@lists.debian.org
Announcing to debian-devel-chan...@lists.debian.org


Thank you for your contribution to Debian.


-- 
To UNSUBSCRIBE, email to debian-qa-packages-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org
Archive: http://lists.debian.org/e1sdquo-0003uk...@franck.debian.org